@@ -11,11 +11,6 @@ describe Facts::Linux::Memory::Swap::UsedBytes do
         receive(:resolve).with(:swap_used_bytes).and_return(value)
     end
 
-    it 'calls Facter::Resolvers::Linux::Memory' do
-      fact.call_the_resolver
-      expect(Facter::Resolvers::Linux::Memory).to have_received(:resolve).with(:swap_used_bytes)
-    end
-
     it 'returns swap used memory in bytes fact' do
       expect(fact.call_the_resolver).to be_an_instance_of(Facter::ResolvedFact).and \
         have_attributes(name: 'memory.swap.used_bytes', value: value)
